@@ -1,6 +1,6 @@
 package UvT::Brebo;
 
-# $Id: Brebo.pm 40847 2014-01-15 15:11:20Z wsl $
+# $Id: Brebo.pm 41894 2014-07-08 13:52:35Z wsl $
 # $URL: https://svn.uvt.nl/its-id/trunk/sources/brebo/lib/UvT/Brebo.pm $
 
 use Clarity -self;
@@ -168,7 +168,7 @@ sub addfile {
 	@headers{@headers} = ();
 
 	foreach(@$required) {
-		die "vereist veld '$_' niet gevonden -- is dit wel het juiste bestand?\n"
+		die "vereiste header '$_' niet gevonden -- is dit wel het juiste bestand?\n"
 			unless exists $headers{$_};
 	}
 
